@@ -17,6 +17,8 @@ async fn main() {
     let bitso = Bitso::default()
         .client_credentials_manager(client_credential)
         .build();
-    let result = bitso.get_user_trades("btc_mxn", None, None, None).await;
+    let result = bitso
+        .get_user_trades(Some("btc_mxn"), None, None, None)
+        .await;
     println!("{:?}", result);
 }
